@@ -136,6 +136,7 @@ typedef struct {
 	size_t buffer_len;
 	int max_priority;
 	unsigned int flag;
+	int option;
 } __vanessa_logger_t;
 
 
@@ -145,13 +146,6 @@ typedef struct {
 
 #define __VANESSA_LOGGER_BUF_SIZE (size_t)1024
 
-#define __VANESSA_LOGGER_SAFE_FREE(ptr) \
-  if(ptr!=NULL){ \
-    free(ptr); \
-    ptr=NULL; \
-  }
-
-
 /**********************************************************************
  * Prototype of internal functions
  **********************************************************************/
@@ -228,7 +222,7 @@ __vanessa_logger_destroy (__vanessa_logger_t * vl)
 	}
 
 	__vanessa_logger_reset(vl);
-	__VANESSA_LOGGER_SAFE_FREE(vl);
+	free(vl);
 }
 
 
@@ -269,13 +263,12 @@ static void __vanessa_logger_reset(__vanessa_logger_t * vl)
 			}
 		}
 		if (vl->data.d_filename != NULL) {
-			__VANESSA_LOGGER_SAFE_FREE(vl->data.d_filename->
-						   filename);
+			free(vl->data.d_filename-> filename);
 		}
-		__VANESSA_LOGGER_SAFE_FREE(vl->data.d_filename);
+		free(vl->data.d_filename);
 		break;
 	case __vanessa_logger_syslog:
-		__VANESSA_LOGGER_SAFE_FREE(vl->data.d_syslog);
+		free(vl->data.d_syslog);
 		if (vl->ready == __vanessa_logger_true) {
 			closelog();
 		}
@@ -293,12 +286,12 @@ static void __vanessa_logger_reset(__vanessa_logger_t * vl)
 	/*
 	 * Reset ident
 	 */
-	__VANESSA_LOGGER_SAFE_FREE(vl->ident);
+	free(vl->ident);
 
 	/*
 	 * Reset buffer, buffer_len
 	 */
-	__VANESSA_LOGGER_SAFE_FREE(vl->buffer);
+	free(vl->buffer);
 	vl->buffer_len = 0;
 
 	/*
@@ -361,9 +354,10 @@ __vanessa_logger_set(__vanessa_logger_t * vl, const char *ident,
 	vl->buffer_len = __VANESSA_LOGGER_BUF_SIZE;
 
 	/*
-	 * Set type
+	 * Set type and option
 	 */
 	vl->type = type;
+	vl->option = option;
 
 	/*
 	 * Set data
@@ -468,6 +462,12 @@ __vanessa_logger_reopen(__vanessa_logger_t * vl)
 		}
 		vl->ready = __vanessa_logger_true;
 		break;
+	case __vanessa_logger_syslog:
+		if (vl->ready == __vanessa_logger_true) {
+			closelog();
+		}
+		openlog(vl->ident, LOG_PID | vl->option, *(vl->data.d_syslog));
+		break;
 	default:
 		break;
 	}
@@ -1249,31 +1249,20 @@ __vanessa_logger_str_dump_oct(vanessa_logger_t * vl,
 			case '"': 
 			case '\'':
 				*out_pos++ = '\\';
-			case ' ':
 				*out_pos++ = *in_pos;
 				continue;
 		}
 		if (isgraph(*in_pos) || *in_pos == ' ') {
 			*out_pos++ = *in_pos;
 		} 
-	 	else {
-			sprintf(out_pos, "\\%03o", *in_pos);
+		else {
+			snprintf(out_pos, 5, "\\%03o", *in_pos & 0xff);
 			out_pos += 4;
 		}
 	}
 
 	*out_pos++ = '\0';
 
-	/* Srink buffer
-	 * Ew, realloc */
-	out = realloc(out, out_pos - out);
-	if (!out) {
-		vanessa_logger_log(vl, LOG_DEBUG, 
-				"vanessa_logger_str_dump: realloc: %s",
-				strerror(errno));
-		return (NULL);
-	}
-
 	return (out);
 }
 
